@@ -1,5 +1,5 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "tabgo" "1.0.1"
+(define-package "tabgo" "20250103.1740"
   "Jump to tabs, avy style."
   '((emacs "27.1"))
   :url "https://github.com/isamert/tabgo.el"
